@@ -1,13 +1,14 @@
 (require "asdf")
 
-;; CL-IRONCLAD does not compile against recent SBCL on 32-bit ARM.
-;; See Debian bug#1016750.
+;; CL-IRONCLAD does not compile against recent SBCL on several 32-bit archs.
+;; See Debian bug#1016750
+;; and <https://github.com/sharplispers/ironclad/issues/53>.
 (when (and (member :sbcl *features*)
 	   (member (or (uiop:getenv "DEB_HOST_ARCH")
 		       (uiop:stripln
 			(uiop:run-program '("dpkg" "--print-architecture")
 					  :output :string)))
-		   '("armel" "armhf") :test #'string=))
+		   '("armel" "armhf" "i386") :test #'string=))
   (uiop:quit 0))
 
 (let ((asdf:*user-cache* (uiop:getenv "AUTOPKGTEST_TMP"))) ; Store FASL in some temporary dir
